# tf2-fm-zoo
Python package repo for the factorization machine implementations from the [tensorflow2_model_zoo](https://github.com/ryancheunggit?tab=repositories) repo.

## Acknowledgement
The original implementation for the methods in this repo were done by [Ren Zhang](https://github.com/ryancheunggit/) who kindly granted permission to use his code for the creation of the package.

